@@ -23,7 +23,7 @@ Usage::
     list_team_members_paginator: ListTeamMembersPaginator = client.get_paginator("list_team_members")
     list_user_profiles_paginator: ListUserProfilesPaginator = client.get_paginator("list_user_profiles")
 """
-from mypy_boto3_codestar.client import CodeStarClient, CodeStarClient as Client
+from mypy_boto3_codestar.client import CodeStarClient as Client, CodeStarClient
 from mypy_boto3_codestar.paginator import (
     ListProjectsPaginator,
     ListResourcesPaginator,
